==> acl2_6.0.orig-books.tar.gz: books/centaur/misc/top.lisp <==
; Centaur Miscellaneous Books
; Copyright (C) 2008-2011 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; This program is free software; you can redistribute it and/or modify it under
; the terms of the GNU General Public License as published by the Free Software
; Foundation; either version 2 of the License, or (at your option) any later
; version.  This program is distributed in the hope that it will be useful but
; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
; more details.  You should have received a copy of the GNU General Public
; License along with this program; if not, write to the Free Software
; Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.

; top.lisp
; Original author: Jared Davis <jared@centtech.com>
;
; This is a silly book that probably never makes sense to include, but it is a
; nice target for the doc book.  The idea is to include every other misc book.

(in-package "ACL2")

(include-book "alist-defs")
(include-book "alist-equiv")
(include-book "ap")
(include-book "defapply")
(include-book "dfs-measure")
(include-book "equal-by-nths")
(include-book "equal-sets")
(include-book "evaluator-metatheorems")
(include-book "fal-graphs")
(include-book "fast-alists")
(include-book "filter-alist")
(include-book "hons-alphorder-merge")
(include-book "hons-extra")
(include-book "hons-remove-dups")
(include-book "hons-sets")
(include-book "interp-function-lookup")
(include-book "ls")
(include-book "memory-mgmt-logic")
(include-book "memory-mgmt-raw")
(include-book "nat-list-duplicates")
(include-book "numlist")
(include-book "patterns")
(include-book "seed-random")
(include-book "sneaky-load")
(include-book "suffixp")
(include-book "tuplep")
(include-book "universal-equiv")
(include-book "vecs-ints")
(include-book "witness-cp")

==> acl2_6.2.orig-books.tar.gz: books/centaur/misc/top.lisp <==
; Centaur Miscellaneous Books
; Copyright (C) 2008-2011 Centaur Technology
;
; Contact:
;   Centaur Technology Formal Verification Group
;   7600-C N. Capital of Texas Highway, Suite 300, Austin, TX 78731, USA.
;   http://www.centtech.com/
;
; This program is free software; you can redistribute it and/or modify it under
; the terms of the GNU General Public License as published by the Free Software
; Foundation; either version 2 of the License, or (at your option) any later
; version.  This program is distributed in the hope that it will be useful but
; WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
; FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
; more details.  You should have received a copy of the GNU General Public
; License along with this program; if not, write to the Free Software
; Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA 02110-1335, USA.

; top.lisp
; Original author: Jared Davis <jared@centtech.com>
;
; This is a silly book that probably never makes sense to include, but it is a
; nice target for the doc book.  The idea is to include every other misc book.

(in-package "ACL2")

(include-book "alist-defs")
(include-book "alist-equiv")
(include-book "ap")
(include-book "defapply")
(include-book "dfs-measure")
(include-book "equal-by-nths")
(include-book "equal-sets")
(include-book "evaluator-metatheorems")
(include-book "fal-graphs")
(include-book "fast-alists")
(include-book "filter-alist")
(include-book "hons-alphorder-merge")
(include-book "hons-extra")
(include-book "hons-remove-dups")
(include-book "hons-sets")
(include-book "interp-function-lookup")
(include-book "memory-mgmt-logic")
(include-book "memory-mgmt")
(include-book "nat-list-duplicates")
(include-book "numlist")
(include-book "patterns")
(include-book "seed-random")
(include-book "sneaky-load")
(include-book "suffixp")
(include-book "tuplep")
(include-book "universal-equiv")
(include-book "vecs-ints")
(include-book "witness-cp")
